==> jc-1.4.0.tar.gz: scm/Mapcar.h <==
// class scm.Mapcar

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 44d5010263e7417e scm_Mapcar
// @dep_class 6d0a82a28dffac88 scm_Procedure

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_Mapcar_H_
#define _JC_scm_Mapcar_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_Mapcar$sub_refs	_jc_scm_Mapcar$sub_refs;
typedef struct _jc_scm_Mapcar$sub_nonrefs	_jc_scm_Mapcar$sub_nonrefs;
typedef struct _jc_scm_Mapcar$refs	_jc_scm_Mapcar$refs;
typedef struct _jc_scm_Mapcar$nonrefs	_jc_scm_Mapcar$nonrefs;
typedef struct _jc_scm_Mapcar$object	_jc_scm_Mapcar$object;

typedef const struct _jc_scm_Mapcar$vmethods	_jc_scm_Mapcar$vmethods;
typedef const struct _jc_scm_Mapcar$vtable	_jc_scm_Mapcar$vtable;
typedef const struct _jc_scm_Mapcar$vtype	_jc_scm_Mapcar$vtype;

// Constructors
extern void _jc_scm_Mapcar$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_Mapcar$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_Mapcar$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_Mapcar$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_Mapcar$method_info$apply$5e27fd10fb01c9e0;

// Virtual methods structure
struct _jc_scm_Mapcar$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_Mapcar$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
};

// Vtable
struct _jc_scm_Mapcar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_Mapcar$vmethods	scm_Mapcar;
};

// Vtype
struct _jc_scm_Mapcar$vtype {
	_jc_type			type;
	_jc_scm_Mapcar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Mapcar$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_Mapcar$refs {
    _jc_scm_Mapcar$sub_refs	scm_Mapcar;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Mapcar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_Mapcar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_Mapcar$sub_nonrefs	scm_Mapcar;
};

// Object instance structure
struct _jc_scm_Mapcar$object {
	_jc_scm_Mapcar$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Mapcar$vtype	*vtype;
	_jc_scm_Mapcar$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Mapcar$vtype _jc_scm_Mapcar$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Mapcar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Mapcar$class_object;

#endif	/* _JC_scm_Mapcar_H_ */

==> jc-1.4.6.tar.gz: scm/Mapcar.h <==
// class scm.Mapcar

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 44d5010263e7417e scm_Mapcar
// @dep_class 6d0a82a28dffac88 scm_Procedure

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_Mapcar_H_
#define _JC_scm_Mapcar_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_Mapcar$sub_refs	_jc_scm_Mapcar$sub_refs;
typedef struct _jc_scm_Mapcar$sub_nonrefs	_jc_scm_Mapcar$sub_nonrefs;
typedef struct _jc_scm_Mapcar$refs	_jc_scm_Mapcar$refs;
typedef struct _jc_scm_Mapcar$nonrefs	_jc_scm_Mapcar$nonrefs;
typedef struct _jc_scm_Mapcar$object	_jc_scm_Mapcar$object;

typedef const struct _jc_scm_Mapcar$vmethods	_jc_scm_Mapcar$vmethods;
typedef const struct _jc_scm_Mapcar$vtable	_jc_scm_Mapcar$vtable;
typedef const struct _jc_scm_Mapcar$vtype	_jc_scm_Mapcar$vtype;

// Constructors
extern void _jc_scm_Mapcar$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_Mapcar$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_Mapcar$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_Mapcar$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_Mapcar$method_info$apply$5e27fd10fb01c9e0;

// Virtual methods structure
struct _jc_scm_Mapcar$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_Mapcar$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_Mapcar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_Mapcar$vmethods	scm_Mapcar;
};

// Vtype
struct _jc_scm_Mapcar$vtype {
	_jc_type			type;
	_jc_scm_Mapcar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Mapcar$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_Mapcar$refs {
    _jc_scm_Mapcar$sub_refs	scm_Mapcar;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Mapcar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_Mapcar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_Mapcar$sub_nonrefs	scm_Mapcar;
};

// Object instance structure
struct _jc_scm_Mapcar$object {
	_jc_scm_Mapcar$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Mapcar$vtype	*vtype;
	_jc_scm_Mapcar$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Mapcar$vtype _jc_scm_Mapcar$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Mapcar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Mapcar$class_object;

#endif	/* _JC_scm_Mapcar_H_ */
